.. image:: ./images/flippr_long_logo.png
    :width: 800

FragPipe Limited-Proteolysis Processor (FLiPPR) is a modular, fast, and easy-to-use data processing tool for LiP-MS & LFQ-based experiments analyzed in FragPipe. It supports differential analysis and label-free quantification workflows.

